<?php

/////////////////////////////////////////////////////////////////////////////
// constants

// various durations, in seconds
define ('DUR_MIN', 60);
define ('DUR_HALF_HOUR', DUR_MIN * 30);
define ('DUR_HOUR', DUR_HALF_HOUR * 2);
define ('DUR_DAY', DUR_HOUR * 24);
define ('DUR_WEEK', DUR_DAY * 7);
define ('DUR_MONTH', DUR_DAY * 30);
define ('DUR_YEAR', (int)(DUR_DAY * 365.25));

$MONTHS = array('janvier',
                'fvrier',
                'mars',
                'avril',
                'mai',
                'juin',
                'juillet',
                'aout',
                'septembre',
                'octobre',
                'novembre',
                'dcembre');

$WEEK_DAYS = array('lundi',
                   'mardi',
                   'mercredi',
                   'jeudi',
                   'vendredi',
                   'samedi',
                   'dimanche');                   

/////////////////////////////////////////////////////////////////////////////
// renders date selection controls
function renderDateSelCtrls($initialTime, $prefix, $min_dyear = 0, $max_dyear = 1, $dmin = 30) {
  global $MONTHS;

  $t = localtime($initialTime, true);
  
  // day
  $res  = '<input name="' . $prefix . '[0]" type="text" size="2" maxlength="2" value="' . $t['tm_mday'] . '">';
  
  // month
  $res .= '<select name="' . $prefix . '[1]">';
  $i = 1;
  foreach ($MONTHS as $month) {
    $res .= "<option value=\"$i\"";
    if ($i == $t['tm_mon'] + 1) $res .= ' selected';
    $res .= ">$month</option>";
    $i++;
  }
  $res .= '</select>';
  
  // year
  $res .= '<select name="' . $prefix . '[2]">';
  for ($i = $min_dyear ; $i <= $max_dyear ; $i++) {
    $year = $t['tm_year'] + 1900 + $i;
    $res .= "<option value=\"$year\"";
    if ($year == $t['tm_year'] + 1900) $res .= ' selected';
    $res .= ">$year</option>";
  }
  $res .= '</select> ';

  // hour
  $res .= '<select name="' . $prefix . '[3]">';
  for ($i = 0 ; $i < 24 ; $i++) {
    $res .= "<option value=\"$i\"";
    if ($i == $t['tm_hour']) $res .= ' selected';
    $res .= ">$i</option>";
  }
  $res .= '</select>:';
  
  // minute
  $res .= '<select name="' . $prefix . '[4]">';
  $minute = $t['tm_min'] - ($t['tm_min'] % $dmin);
  for ($i = 0 ; $i < 60 ; $i += $dmin) {    
    $res .= "<option value=\"$i\"";
    if ($i == $minute) $res .= ' selected';
    $res .= ">$i</option>";
  }
  $res .= '</select>';
  
  return $res;
}

/////////////////////////////////////////////////////////////////////////////
function timeStampFromCtrls($t) {
  return mktime($t[3], 
                $t[4],
                0,
                $t[1],
                $t[0],
                $t[2]);                
}

/////////////////////////////////////////////////////////////////////////////
function renderHourSelCtrls($aName, $start, $end, $delta = DUR_HALF_HOUR, $maxSize = 24, $periods = '') {
  $res = '';

  // expand periods string to an array
  if ($periods != '') {
    $intervals = split('[{}]', $periods);
    $nbElts = count($intervals);
    for ($i = 0 ; $i < $nbElts ; $i++) {
      $intervals[$i] = split(';', $intervals[$i]);
    }
    $nbIntervals = count($intervals);
  }
    
  if (($end - $start) <= DUR_DAY) {
    $timeFmt = "%H:%M";
    $size = min((int)(($end - $start) / DUR_HOUR) * 2, $maxSize);

    $res .= "<select name=\"" . $aName . "[]\" multiple size=\"$size\">";
    for ($i = $start ; $i < $end ; $i += $delta) {
      $t1 = $i;
      $t2 = $i + $delta;
      
      $selected = '';      
      if ($periods != '') {
        // see if t1 and t2 are contained in user's intervals
        for ($j = 0 ; $j < $nbIntervals ; $j++) {
          if (($t1 >= $intervals[$j][0]) && ($t2 <= $intervals[$j][1]))
            $selected = ' selected';
        }
      }
      
      $res .= "<option value=\"" . $t1 . '-' . $t2 . "\" $selected>";
      $res .= strftime($timeFmt, $t1);
      $res .= ' - ';
      $res .= strftime($timeFmt, $t2);
      $res .= "\n";
    }
    $res .= '</select>';
  }

  return $res;  
}

/////////////////////////////////////////////////////////////////////////////
// converts the array resulting from the controls above to a set of time
// intervals, in the form :
// {t1;t2} ... {tn;tn+1}
// the intervals are 'compressed' to avoid contigous redudancy

function intervalsFromCtrls($hours) {
  $lastEnd = 0;
  $nbElts = count($hours);
  for ($i = 0 ; $i < $nbElts ; $i++) {
    $parts = split('-', $hours[$i]);
    
    if ($parts[0] != $lastEnd) {
      if ($lastEnd != 0) {
        $res .= $lastEnd . '}';
      }
      $res .= '{' . $parts[0] . ';';
    }
    
    $lastEnd = $parts[1];
  }
  $res .= $parts[1] . '}';
  
  return $res;  
}

?>
